@@ -47,6 +47,8 @@ const gchar *type;
 GdkAtom pdfscreenshot_atom;
 char *supported_str = "supported";
 
+XErrorHandler old_handler = (XErrorHandler) 0 ;
+
 /*
  * This function handles the file type combo box callback in the Save As
  * dialogue. I would have expected that such functionality is already provided
@@ -290,6 +292,18 @@ pdfscreenshot_window_create()
     gtk_widget_show_all(GTK_WIDGET(window));
 }
 
+/* 
+ * Ignore all BadWindow errors.
+ */
+int
+silent_error_handler (Display *display, XErrorEvent *error) 
+{
+    if (error->error_code != BadWindow) {
+        return old_handler (display, error);
+    }
+    return 0;
+}
+
 GdkFilterReturn
 pdfscreenshot_event_filter (GdkXEvent *xevent, GdkEvent *event, gpointer data)
 {
@@ -297,12 +311,22 @@ pdfscreenshot_event_filter (GdkXEvent *xevent, GdkEvent *event, gpointer data)
 
     if (ev->type == MapNotify) {
         XTextProperty supported;
+        GdkDisplay *display = gdk_x11_lookup_xdisplay(ev->xmap.display);
+
         XStringListToTextProperty(&supported_str, 1, &supported);
 
+        if (display)
+            gdk_x11_display_error_trap_push(display);
+        else
+            gdk_error_trap_push();
         XSetTextProperty(ev->xmap.display,
             ev->xmap.window,
             &supported,
             gdk_x11_atom_to_xatom(pdfscreenshot_atom));
+        if (display)
+            gdk_x11_display_error_trap_pop_ignored(display);
+        else
+            gdk_error_trap_pop_ignored();
     } else if (ev->type == ClientMessage &&
             ev->xclient.message_type == gdk_x11_atom_to_xatom(pdfscreenshot_atom)) {
         if (event->any.window != NULL) {
